==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/62/62574d6cd0626d3304f2269fce3d5864.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Doctrine/Loader/FixturesLoaderInterface.php */
class __TwigTemplate_0faaca3b4813b2465f3f0f3186905489 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Doctrine\\Loader;

use Doctrine\\Common\\DataFixtures\\FixtureInterface;

interface FixturesLoaderInterface
{
    /**
     * Returns the array of data fixtures to execute.
     *
     * @param string[] \$groups
     *
     * @return FixtureInterface[]
     */
    public function getFixtures(array \$groups = []): array;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Doctrine/Loader/FixturesLoaderInterface.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Doctrine/Loader/FixturesLoaderInterface.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Doctrine/Loader/FixturesLoaderInterface.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/62/62574d6cd0626d3304f2269fce3d5864.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Doctrine/Loader/FixturesLoaderInterface.php */
class __TwigTemplate_0faaca3b4813b2465f3f0f3186905489 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Doctrine\\Loader;

use Doctrine\\Common\\DataFixtures\\FixtureInterface;

interface FixturesLoaderInterface
{
    /**
     * Returns the array of data fixtures to execute.
     *
     * @param string[] \$groups
     *
     * @return FixtureInterface[]
     */
    public function getFixtures(array \$groups = []): array;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Doctrine/Loader/FixturesLoaderInterface.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Doctrine/Loader/FixturesLoaderInterface.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Doctrine/Loader/FixturesLoaderInterface.php");
    }
}
